@@ -4,8 +4,6 @@ import re
 import pytest
 from marshmallow import fields, validate
 
-from apispec.ext.marshmallow.openapi import MARSHMALLOW_VERSION_INFO
-
 from .schemas import CategorySchema, CustomList, CustomStringField, CustomIntegerField
 from .utils import build_ref
 
@@ -61,8 +59,6 @@ def test_formatted_field_translates_to_array(ListClass, spec_fixture):
 @pytest.mark.parametrize(
     ("FieldClass", "expected_format"),
     [
-        (fields.Integer, "int32"),
-        (fields.Float, "float"),
         (fields.UUID, "uuid"),
         (fields.DateTime, "date-time"),
         (fields.Date, "date"),
@@ -95,10 +91,7 @@ def test_boolean_field_with_false_missing(spec_fixture):
 
 
 def test_datetime_field_with_missing(spec_fixture):
-    if MARSHMALLOW_VERSION_INFO[0] < 3:
-        field = fields.Date(missing=dt.date(2014, 7, 18).isoformat())
-    else:
-        field = fields.Date(missing=dt.date(2014, 7, 18))
+    field = fields.Date(missing=dt.date(2014, 7, 18))
     res = spec_fixture.openapi.field2property(field)
     assert res["default"] == dt.date(2014, 7, 18).isoformat()
 
