@@ -229,6 +229,31 @@ class TestMarshmallowSchemaToParameters:
         res = openapi._field2parameter(field, name="field", location="query")
         assert res["required"] is True
 
+    def test_schema_partial(self, openapi):
+        class UserSchema(Schema):
+            field = fields.Str(required=True)
+
+        res_nodump = openapi.schema2parameters(
+            UserSchema(partial=True), location="query"
+        )
+
+        param = res_nodump[0]
+        assert param["required"] is False
+
+    def test_schema_partial_list(self, openapi):
+        class UserSchema(Schema):
+            field = fields.Str(required=True)
+            partial_field = fields.Str(required=True)
+
+        res_nodump = openapi.schema2parameters(
+            UserSchema(partial=("partial_field",)), location="query"
+        )
+
+        param = next(p for p in res_nodump if p["name"] == "field")
+        assert param["required"] is True
+        param = next(p for p in res_nodump if p["name"] == "partial_field")
+        assert param["required"] is False
+
     # json/body is invalid for OpenAPI 3
     @pytest.mark.parametrize("openapi", ("2.0",), indirect=True)
     def test_schema_body(self, openapi):
